@@ -1,5 +1,11 @@
 """
-Idempotent API for managing Redis instances
+Redis
+=====
+
+This module provides high-level tools for managing `Redis`_ instances.
+
+.. _Redis: http://redis.io/
+
 """
 from __future__ import with_statement
 
@@ -7,7 +13,7 @@ from fabtools.files import is_file, watch
 from fabtools.deb import *
 
 
-VERSION='2.4.8'
+VERSION = '2.4.17'
 
 BINARIES = [
     'redis-benchmark',
@@ -20,7 +26,9 @@ BINARIES = [
 
 def installed_from_source(version=VERSION):
     """
-    Require Redis to be installed from source
+    Require Redis to be installed from source.
+
+    The compiled binaries will be installed in ``/opt/redis-{version}/``.
     """
     from fabtools import require
 
@@ -50,9 +58,28 @@ def installed_from_source(version=VERSION):
 
 def instance(name, version=VERSION, **kwargs):
     """
-    Require a Redis instance to be running
+    Require a Redis instance to be running.
+
+    The instance will be managed using supervisord, as a process named
+    ``redis_{name}``, running as the ``redis`` user.
+
+    ::
+
+        from fabtools import require
+        from fabtools.supervisor import process_status
+
+        require.redis.installed_from_source()
+
+        require.redis.instance('db1', port='6379')
+        require.redis.instance('db2', port='6380')
+
+        print process_status('redis_db1')
+        print process_status('redis_db2')
+
+    .. seealso:: :ref:`supervisor_module` and
+                 :ref:`require_supervisor_module`
+
 
-    The instance will be managed using supervisord.
     """
     from fabtools import require
 
@@ -64,7 +91,8 @@ def instance(name, version=VERSION, **kwargs):
     require.directory('/var/run/redis', use_sudo=True, owner='redis')
 
     # Required for background saving
-    require.system.sysctl('vm.overcommit_memory', '1')
+    with settings(warn_only=True):
+        require.system.sysctl('vm.overcommit_memory', '1')
 
     # Set default parameters
     params = {}
@@ -90,10 +118,7 @@ def instance(name, version=VERSION, **kwargs):
     config_filename = '/etc/redis/%(name)s.conf' % locals()
 
     # Upload config file
-    need_restart = False
-    def on_change():
-        need_restart = True
-    with watch(config_filename, True, on_change):
+    with watch(config_filename, use_sudo=True) as config:
         require.file(config_filename, contents='\n'.join(lines),
             use_sudo=True, owner='redis')
 
@@ -103,5 +128,7 @@ def instance(name, version=VERSION, **kwargs):
         user='redis',
         directory='/var/run/redis',
         command="%(redis_server)s %(config_filename)s" % locals())
-    if need_restart:
+
+    # Restart if needed
+    if config.changed:
         fabtools.supervisor.restart_process(process_name)
