@@ -1,9 +1,15 @@
+"""
+Vagrant helpers
+===============
+"""
+from __future__ import with_statement
+
 from fabric.api import *
 
 
 def ssh_config(name=''):
     """
-    Get the SSH parameters for a vagrant VM
+    Get the SSH parameters for connecting to a vagrant VM.
     """
     with settings(hide('running')):
         output = local('vagrant ssh-config %s' % name, capture=True)
@@ -34,7 +40,21 @@ def _settings_dict(config):
 @task
 def vagrant(name=''):
     """
-    Run the following tasks on a vagrant box
+    Run the following tasks on a vagrant box.
+
+    First, you need to import this task in your ``fabfile.py``::
+
+        from fabric.api import *
+        from fabtools.vagrant import vagrant
+
+        @task
+        def some_task():
+            run('echo hello')
+
+    Then you can easily run tasks on your current Vagrant box::
+
+        $ fab vagrant some_task
+
     """
     config = ssh_config(name)
 
@@ -45,7 +65,15 @@ def vagrant(name=''):
 def vagrant_settings(name='', *args, **kwargs):
     """
     Context manager that sets a vagrant VM
-    as the remote host
+    as the remote host.
+
+    Use this context manager inside a task to run commands
+    on your current Vagrant box::
+
+        from fabtools.vagrant import vagrant_settings
+
+        with vagrant_settings():
+            run('hostname')
     """
     config = ssh_config(name)
 
